downloadTSet: Download a ToxicoSet object
Description
This function allows you to download a ToxicoSet object for use with this
package. The ToxicoSets have been extensively curated and organised within
a PharacoSet class, enabling use with all the analysis tools provided in
PharmacoGx.
Usage
downloadTSet(name, saveDir = tempdir(), tSetFileName = NULL, verbose = TRUE)
Arguments
name
Character string, the name of the PhamracoSet to download.
saveDir
Character string with the folder path where the
ToxicoSet should be saved. Defaults to './tSets/'. Will create
directory if it does not exist.
tSetFileName
character string, the file name to save the dataset under
verbose
bool Should status messages be printed during download.
Defaults to TRUE.
Value
A tSet object with the dataset, downloaded from our server
Examples
Run this code# NOT RUN {
if (interactive()){
downloadtSet("TGGATESvignette")
}
# }
Run the code above in your browser using DataLab